==> openshift-model-machine-5.10.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineSetSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class MachineSetSpecFluentImpl<A extends io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent<A>{
  public MachineSetSpecFluentImpl() {
  }
  public MachineSetSpecFluentImpl(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpec instance) {
    this.withDeletePolicy(instance.getDeletePolicy()); 
    this.withMinReadySeconds(instance.getMinReadySeconds()); 
    this.withReplicas(instance.getReplicas()); 
    this.withSelector(instance.getSelector()); 
    this.withTemplate(instance.getTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String deletePolicy;
  private java.lang.Integer minReadySeconds;
  private java.lang.Integer replicas;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder selector;
  private io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder template;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDeletePolicy() {
    return this.deletePolicy;
  }
  public A withDeletePolicy(java.lang.String deletePolicy) {
    this.deletePolicy=deletePolicy; return (A) this;
  }
  public java.lang.Boolean hasDeletePolicy() {
    return this.deletePolicy != null;
  }
  
  /**
   * Method is deprecated. use withDeletePolicy instead.
   */
  @java.lang.Deprecated
  public A withNewDeletePolicy(java.lang.String arg0) {
    return (A)withDeletePolicy(new String(arg0));
  }
  public java.lang.Integer getMinReadySeconds() {
    return this.minReadySeconds;
  }
  public A withMinReadySeconds(java.lang.Integer minReadySeconds) {
    this.minReadySeconds=minReadySeconds; return (A) this;
  }
  public java.lang.Boolean hasMinReadySeconds() {
    return this.minReadySeconds != null;
  }
  public java.lang.Integer getReplicas() {
    return this.replicas;
  }
  public A withReplicas(java.lang.Integer replicas) {
    this.replicas=replicas; return (A) this;
  }
  public java.lang.Boolean hasReplicas() {
    return this.replicas != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
  }
  public java.lang.Boolean hasSelector() {
    return this.selector != null;
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<A> withNewSelector() {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluentImpl.SelectorNestedImpl();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluentImpl.SelectorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec getTemplate() {
    return this.template!=null?this.template.build():null;
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec buildTemplate() {
    return this.template!=null?this.template.build():null;
  }
  public A withTemplate(io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder(template); _visitables.get("template").add(this.template);} return (A) this;
  }
  public java.lang.Boolean hasTemplate() {
    return this.template != null;
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<A> withNewTemplate() {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluentImpl.TemplateNestedImpl();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<A> withNewTemplateLike(io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec item) {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluentImpl.TemplateNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<A> editOrNewTemplateLike(io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MachineSetSpecFluentImpl that = (MachineSetSpecFluentImpl) o;
    if (deletePolicy != null ? !deletePolicy.equals(that.deletePolicy) :that.deletePolicy != null) return false;
    if (minReadySeconds != null ? !minReadySeconds.equals(that.minReadySeconds) :that.minReadySeconds != null) return false;
    if (replicas != null ? !replicas.equals(that.replicas) :that.replicas != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    if (template != null ? !template.equals(that.template) :that.template != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(deletePolicy,  minReadySeconds,  replicas,  selector,  template,  additionalProperties,  super.hashCode());
  }
  public class SelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<N>> implements io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) MachineSetSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  public class TemplateNestedImpl<N> extends io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<N>> implements io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TemplateNestedImpl(io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec item) {
      this.builder = new io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder(this);
    }
    io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder builder;
    public N and() {
      return (N) MachineSetSpecFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}

==> openshift-model-machine-5.12.3-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineSetSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class MachineSetSpecFluentImpl<A extends io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent<A>{
  public MachineSetSpecFluentImpl() {
  }
  public MachineSetSpecFluentImpl(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpec instance) {
    this.withDeletePolicy(instance.getDeletePolicy()); 
    this.withMinReadySeconds(instance.getMinReadySeconds()); 
    this.withReplicas(instance.getReplicas()); 
    this.withSelector(instance.getSelector()); 
    this.withTemplate(instance.getTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String deletePolicy;
  private java.lang.Integer minReadySeconds;
  private java.lang.Integer replicas;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder selector;
  private io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder template;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDeletePolicy() {
    return this.deletePolicy;
  }
  public A withDeletePolicy(java.lang.String deletePolicy) {
    this.deletePolicy=deletePolicy; return (A) this;
  }
  public java.lang.Boolean hasDeletePolicy() {
    return this.deletePolicy != null;
  }
  
  /**
   * Method is deprecated. use withDeletePolicy instead.
   */
  @java.lang.Deprecated
  public A withNewDeletePolicy(java.lang.String arg0) {
    return (A)withDeletePolicy(new String(arg0));
  }
  public java.lang.Integer getMinReadySeconds() {
    return this.minReadySeconds;
  }
  public A withMinReadySeconds(java.lang.Integer minReadySeconds) {
    this.minReadySeconds=minReadySeconds; return (A) this;
  }
  public java.lang.Boolean hasMinReadySeconds() {
    return this.minReadySeconds != null;
  }
  public java.lang.Integer getReplicas() {
    return this.replicas;
  }
  public A withReplicas(java.lang.Integer replicas) {
    this.replicas=replicas; return (A) this;
  }
  public java.lang.Boolean hasReplicas() {
    return this.replicas != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
  }
  public java.lang.Boolean hasSelector() {
    return this.selector != null;
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<A> withNewSelector() {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluentImpl.SelectorNestedImpl();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluentImpl.SelectorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec getTemplate() {
    return this.template!=null?this.template.build():null;
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec buildTemplate() {
    return this.template!=null?this.template.build():null;
  }
  public A withTemplate(io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder(template); _visitables.get("template").add(this.template);} return (A) this;
  }
  public java.lang.Boolean hasTemplate() {
    return this.template != null;
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<A> withNewTemplate() {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluentImpl.TemplateNestedImpl();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<A> withNewTemplateLike(io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec item) {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluentImpl.TemplateNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<A> editOrNewTemplateLike(io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MachineSetSpecFluentImpl that = (MachineSetSpecFluentImpl) o;
    if (deletePolicy != null ? !deletePolicy.equals(that.deletePolicy) :that.deletePolicy != null) return false;
    if (minReadySeconds != null ? !minReadySeconds.equals(that.minReadySeconds) :that.minReadySeconds != null) return false;
    if (replicas != null ? !replicas.equals(that.replicas) :that.replicas != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    if (template != null ? !template.equals(that.template) :that.template != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(deletePolicy,  minReadySeconds,  replicas,  selector,  template,  additionalProperties,  super.hashCode());
  }
  public class SelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<N>> implements io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) MachineSetSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  public class TemplateNestedImpl<N> extends io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<N>> implements io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent.TemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TemplateNestedImpl(io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpec item) {
      this.builder = new io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder(this);
    }
    io.fabric8.openshift.api.model.machine.v1beta1.MachineTemplateSpecBuilder builder;
    public N and() {
      return (N) MachineSetSpecFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}
